

import 'package:sql_build_database/sbd_colum_datata_type.dart';

class SBDColumn<T1> {
  final types = ['INTEGER', 'TEXT', 'REAL', 'BLOB'];
  String name;
  final SBDColumDataType type;
  final bool isUnique;
  final bool isNotNull;
  final T1 defaultValue;
  final bool isPrimaryKey;
  final bool isAutoIncrement;
  final List<String> foreignKey;

  SBDColumn({
    this.name,
    this.type = SBDColumDataType.TEXT,
    this.isPrimaryKey = false,
    this.isUnique = false,
    this.isNotNull = false,
    this.defaultValue,
    this.isAutoIncrement = false,
    this.foreignKey,
  });

  String get getType => types[this.type.index];

  void setName(String name) {
    this.name = name;
  }

  build() {
    List<String> column = [];

    column.add(name);

    column.add(types[type.index]);

    if (isPrimaryKey) {
      column.add('PRIMARY KEY');
    } else {
      column.add(isNotNull ? 'NOT NULL' : 'NULL');
    }

    if (isUnique) {
      column.add('UNIQUE');
    }

    if (isAutoIncrement) {
      column.add('AUTOINCREMENT');
    }

    if (defaultValue != null) {
      column.add('DEFAULT $defaultValue');
    }

    if (foreignKey != null) {
      column.add("REFERENCES " + foreignKey[0] + '(' + foreignKey[1] + ')');
    }

    return column.join(' ');
  }
}
